@@ -1,6 +1,7 @@
-from collections import defaultdict
 import re
 import operator
+from six.moves import reduce
+import six
 
 REX_CACHE = {}
 
@@ -17,12 +18,15 @@ class RexMatch(dict):
         except KeyError:
             return None
 
+    def get(self, k, d=None):
+        ret = super(RexMatch, self).get(k, d)
+        return d if ret is None else ret
+
     def __str__(self):
         return str(self[0]) if self[0] else ''
 
     def __unicode__(self):
-        return unicode(self[0]) if self[0] else u''
-
+        return six.u(self[0]) if self[0] else u''
 
 
 class Rex(object):
@@ -43,15 +47,14 @@ class Rex(object):
         self.replacement = replacement
         self.re = re.compile(self.pattern, self.flags)
 
-
     def __process(self, text):
         if self.action == 'm':
             result = RexMatch()
             match = self.re.search(text)
             if match is not None:
+                rex.group = result
                 result[0] = match.group()
-                for i, m in enumerate(match.groups()):
-                    result[i + 1] = m
+                result.update(enumerate(match.groups(), start=1))
                 result.update(match.groupdict())
             return result
         elif self.action == 's':
@@ -60,6 +63,9 @@ class Rex(object):
     def __eq__(self, other):
         return self.__process(other)
 
+    def __call__(self, text):
+        return self.__process(text)
+
 
 def rex(expression, text=None, cache=True):
     rex_obj = REX_CACHE.get(expression, None)
@@ -90,7 +96,7 @@ def rex(expression, text=None, cache=True):
         pattern = pattern[:index]
 
     try:
-        re_flags = map(lambda f: Rex.FLAGS[f], expression[end + 1:])
+        re_flags = [Rex.FLAGS[f] for f in expression[end + 1:]]
     except KeyError:
         raise ValueError('Bad flags')
 
@@ -102,8 +108,9 @@ def rex(expression, text=None, cache=True):
         return text == rex_obj
     else:
         return rex_obj
+rex.group = RexMatch()
 
 
 def rex_clear_cache():
     global REX_CACHE
-    REX_CACHE = {}
\ No newline at end of file
+    REX_CACHE = {}
